;; Generated package description from gpr-mode.el  -*- no-byte-compile: t -*-
(define-package "gpr-mode" "1.0.1.0.20221212.224547" "Major mode for editing GNAT project files" '((emacs "25.3") (wisi "4.1.1") (gnat-compiler "1.0")) :commit "eb53a24c6d6e478e0718196caf78d37e668b2bbd" :authors '(("Stephen Leake" . "stephen_leake@member.fsf.org")) :maintainer '("Stephen Leake" . "stephen_leake@member.fsf.org") :url "http://stephe-leake.org/ada/wisitoken.html")
